WorkingNFA

Struct WorkingNFA 

pub struct WorkingNFA { /* private fields */ }
Each NFA has one start state (0) and one accept state (states.len() - 1)

Implementations

Source

impl WorkingNFA

pub fn build(tree: &SimplifiedTreeNode) -> WorkingNFA

Recursively builds an inefficient but valid NFA based loosely on Thompson’s Algorithm.

Should be optimized using WorkingNFA::optimize_pass

pub fn new(tree: &SimplifiedTreeNode) -> WorkingNFA

pub fn num_capture_groups(&self) -> usize

Finds the number of capture groups in this NFA

pub fn capture_group_is_optional(&self, group_num: usize) -> bool

Returns whether each there is any matching path where the capture group is unused

pub fn to_tikz(&self, include_doc: bool) -> String

Writes a LaTeX TikZ representation to visualize the graph.

If include_doc is true, will include the headers. Otherwise, you should include \usepackage{tikz} and \usetikzlibrary{automata, positioning}.

pub fn test(&self, text: &str) -> bool

Using the classical NFA algorithm to do a simple boolean test on a string.