Enum AmbiguousSubmatchMode

pub enum AmbiguousSubmatchMode {
    Greedy,
}

Variants



Greedy

While not POSIX standard, the greedy method for determining ambiguous submatches is able to be implemented the most efficiently in the general case. This is based on the popular Perl regex rules for ambiguous submatching.

  • Quantifiers match as much as possible while allowing the rest to match
  • Alternations prioritize the earlier options
  • Since it is greedy, the leftmost quantifier/alternations will match first.