pub struct WorkingNFA { /* private fields */ }Expand description
Each NFA has one start state (0) and one accept state (states.len() - 1)
Implementations
Sourceimpl WorkingNFA
impl WorkingNFA
Sourcepub fn build(tree: &SimplifiedTreeNode) -> WorkingNFA
pub fn build(tree: &SimplifiedTreeNode) -> WorkingNFA
Recursively builds an inefficient but valid NFA based loosely on Thompson’s Algorithm.
Should be optimized using WorkingNFA::optimize_pass
pub fn new(tree: &SimplifiedTreeNode) -> WorkingNFA
Sourcepub fn num_capture_groups(&self) -> usize
pub fn num_capture_groups(&self) -> usize
Finds the number of capture groups in this NFA
Sourcepub fn capture_group_is_optional(&self, group_num: usize) -> bool
pub fn capture_group_is_optional(&self, group_num: usize) -> bool
Returns whether each there is any matching path where the capture group is unused